@@ -1,10 +1,11 @@
 #include <string.h>
+#include <stdint.h>
 
 #include "buffer.h"
 #include "etag.h"
 
 int etag_is_equal(buffer *etag, const char *matches) {
-	if (0 == strcmp(etag->ptr, matches)) return 1;
+	if (etag && !buffer_is_empty(etag) && 0 == strcmp(etag->ptr, matches)) return 1;
 	return 0;
 }
 
@@ -31,7 +32,8 @@ int etag_create(buffer *etag, struct stat *st,etag_flags_t flags) {
 }
 
 int etag_mutate(buffer *mut, buffer *etag) {
-	size_t h, i;
+	size_t i;
+	uint32_t h;
 
 	for (h=0, i=0; i < etag->used; ++i) h = (h<<5)^(h>>27)^(etag->ptr[i]);
 
