@@ -31,11 +31,6 @@
 
 #include "sys-socket.h"
 
-
-#ifndef UNIX_PATH_MAX
-# define UNIX_PATH_MAX 108
-#endif
-
 #ifdef HAVE_SYS_UIO_H
 #include <sys/uio.h>
 #endif
@@ -1027,8 +1022,9 @@ SETDEFAULTS_FUNC(mod_scgi_set_defaults) {
 
 					if (!buffer_is_empty(df->unixsocket)) {
 						/* unix domain socket */
+						struct sockaddr_un un;
 
-						if (df->unixsocket->used > UNIX_PATH_MAX - 2) {
+						if (df->unixsocket->used > sizeof(un.sun_path) - 2) {
 							log_error_write(srv, __FILE__, __LINE__, "s",
 									"path of the unixdomain socket is too large");
 							return HANDLER_ERROR;
@@ -1430,7 +1426,7 @@ static int scgi_create_env(server *srv, handler_ctx *hctx) {
 	/* CGI-SPEC 6.1.2, FastCGI spec 6.3 and SCGI spec */
 
 	/* request.content_length < SSIZE_MAX, see request.c */
-	ltostr(buf, con->request.content_length);
+	LI_ltostr(buf, con->request.content_length);
 	scgi_env_add(p->scgi_env, CONST_STR_LEN("CONTENT_LENGTH"), buf, strlen(buf));
 	scgi_env_add(p->scgi_env, CONST_STR_LEN("SCGI"), CONST_STR_LEN("1"));
 
@@ -1454,7 +1450,7 @@ static int scgi_create_env(server *srv, handler_ctx *hctx) {
 
 	scgi_env_add(p->scgi_env, CONST_STR_LEN("GATEWAY_INTERFACE"), CONST_STR_LEN("CGI/1.1"));
 
-	ltostr(buf,
+	LI_ltostr(buf,
 #ifdef HAVE_IPV6
 	       ntohs(srv_sock->addr.plain.sa_family ? srv_sock->addr.ipv6.sin6_port : srv_sock->addr.ipv4.sin_port)
 #else
@@ -1474,7 +1470,7 @@ static int scgi_create_env(server *srv, handler_ctx *hctx) {
 	}
 	scgi_env_add(p->scgi_env, CONST_STR_LEN("SERVER_ADDR"), s, strlen(s));
 
-	ltostr(buf,
+	LI_ltostr(buf,
 #ifdef HAVE_IPV6
 	       ntohs(con->dst_addr.plain.sa_family ? con->dst_addr.ipv6.sin6_port : con->dst_addr.ipv4.sin_port)
 #else
